# py-lmd

The py-lmd library allows to read, modify and write shape files for the Leica LMD6 & LMD7 microscope.
Additionally, functionality for the calibration, generation of final pulses and import of vektor files is included.
